==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebDialogDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebDialogDescription } from "./WebDialogDescription";
/**
 * @hidden
 */
export let WebDialogDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDialogDescriptionMetadata extends Base {
        static b(a) {
            if (WebDialogDescriptionMetadata.a == null) {
                WebDialogDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDialogDescriptionMetadata.c(WebDialogDescriptionMetadata.a);
            }
            if (a.k(WebDialogDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebDialogDescriptionMetadata.a);
            VoidEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Dialog");
            a.item("__tagNameWC", "String:igc-dialog");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("KeepOpenOnEscape", "Boolean");
            a.item("CloseOnOutsideClick", "Boolean");
            a.item("HideDefaultAction", "Boolean");
            a.item("Open", "Boolean");
            a.item("Title", "String");
            a.item("ReturnValue", "String");
            a.item("ClosingRef", "EventRef::closing");
            a.item("ClosedRef", "EventRef::closed");
        }
        static d(a) {
            WebDialogDescriptionMetadata.b(a);
            a.ad("WebDialog", () => new WebDialogDescription());
            a.ac("WebDialog", WebDialogDescriptionMetadata.a);
        }
    }
    WebDialogDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDialogDescriptionMetadata, 'WebDialogDescriptionMetadata');
    WebDialogDescriptionMetadata.a = null;
    return WebDialogDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebDialogDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebDialogDescription } from "./WebDialogDescription";
/**
 * @hidden
 */
export let WebDialogDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDialogDescriptionMetadata extends Base {
        static b(a) {
            if (WebDialogDescriptionMetadata.a == null) {
                WebDialogDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDialogDescriptionMetadata.c(WebDialogDescriptionMetadata.a);
            }
            if (a.k(WebDialogDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebDialogDescriptionMetadata.a);
            VoidEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Dialog");
            a.item("__tagNameWC", "String:igc-dialog");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("KeepOpenOnEscape", "Boolean");
            a.item("CloseOnOutsideClick", "Boolean");
            a.item("HideDefaultAction", "Boolean");
            a.item("Open", "Boolean");
            a.item("Title", "String");
            a.item("ReturnValue", "String");
            a.item("ClosingRef", "EventRef::closing");
            a.item("ClosedRef", "EventRef::closed");
        }
        static d(a) {
            WebDialogDescriptionMetadata.b(a);
            a.ae("WebDialog", () => new WebDialogDescription());
            a.ad("WebDialog", WebDialogDescriptionMetadata.a);
        }
    }
    WebDialogDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDialogDescriptionMetadata, 'WebDialogDescriptionMetadata');
    WebDialogDescriptionMetadata.a = null;
    return WebDialogDescriptionMetadata;
})();
